npm - Betty documentation

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# npm

Some optional parts of Betty use third-party JavaScript packages to help build your site.

If Betty shows you an error telling you you need npm or Node.js, then in order to use that functionality, you must:

- install Node.js following the instructions shown there

- ensure `npm` (the Node.js package manager) is in your `PATH`, e.g. that `npm` can be run in a terminal from anywhere. When running `npm --help` in a terminal shows you npm’s usage instructions, then you’re all set.